==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/kernel/single/core/src/test/java/org/apache/shardingsphere/single/metadata/reviser/SingleMetaDataReviseEntryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.single.metadata.reviser;

import org.apache.shardingsphere.single.config.SingleRuleConfiguration;
import org.apache.shardingsphere.single.metadata.reviser.constraint.SingleConstraintReviser;
import org.apache.shardingsphere.single.rule.SingleRule;
import org.junit.jupiter.api.Test;

import java.util.Collections;
import java.util.HashMap;
import java.util.Optional;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.jupiter.api.Assertions.assertTrue;

class SingleMetaDataReviseEntryTest {
    
    private final SingleMetaDataReviseEntry reviseEntry = new SingleMetaDataReviseEntry();
    
    @Test
    void assertGetConstraintReviser() {
        SingleRuleConfiguration ruleConfig = new SingleRuleConfiguration();
        SingleRule rule = new SingleRule(ruleConfig, "test_database", null, new HashMap<>(), Collections.emptyList());
        String tableName = "test_table";
        Optional<SingleConstraintReviser> constraintReviser = reviseEntry.getConstraintReviser(rule, tableName);
        assertTrue(constraintReviser.isPresent());
        assertThat(constraintReviser.get().getClass(), is(SingleConstraintReviser.class));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/kernel/single/core/src/test/java/org/apache/shardingsphere/single/metadata/reviser/SingleMetaDataReviseEntryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.single.metadata.reviser;

import org.apache.shardingsphere.single.config.SingleRuleConfiguration;
import org.apache.shardingsphere.single.metadata.reviser.constraint.SingleConstraintReviser;
import org.apache.shardingsphere.single.rule.SingleRule;
import org.junit.jupiter.api.Test;

import java.util.Collections;
import java.util.HashMap;
import java.util.Optional;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.jupiter.api.Assertions.assertTrue;

class SingleMetaDataReviseEntryTest {
    
    private final SingleMetaDataReviseEntry reviseEntry = new SingleMetaDataReviseEntry();
    
    @Test
    void assertGetConstraintReviser() {
        SingleRuleConfiguration ruleConfig = new SingleRuleConfiguration();
        SingleRule rule = new SingleRule(ruleConfig, "test_database", null, new HashMap<>(), Collections.emptyList());
        String tableName = "test_table";
        Optional<SingleConstraintReviser> constraintReviser = reviseEntry.getConstraintReviser(rule, tableName);
        assertTrue(constraintReviser.isPresent());
        assertThat(constraintReviser.get().getClass(), is(SingleConstraintReviser.class));
    }
}
